@@ -13,7 +13,7 @@ use Masterkey::Admin::Config;
 use Masterkey::Admin::Torus;
 
 our @ISA = qw();
-our $VERSION = '4.1';
+our $VERSION = '4.2';
 
 sub new {
     my $class = shift();
@@ -173,8 +173,7 @@ sub new_with_session {
 	die "Invalid user-ID '$uid'" if !defined $user;
 
 	# Special case: consortium-level administrator is always super
-	$user->{layers}->{final}->{fields}->{superuser} = 1
-	    if $domain eq "wizard";
+	$user->setField(superuser => 1) if $domain eq "wizard";
     }
 
   DONE:
