@@ -15,7 +15,7 @@ sub new {
     my $class = shift();
     my($admin, $usiParam, $record) = @_;
 
-    if ($usiParam || $admin->configValue("usiBaseUrl")) {
+    if ($usiParam || $admin->conf("usiBaseUrl")) {
 	return new Masterkey::Admin::Test::USI(@_);
     } else {
 	return new Masterkey::Admin::Test::NonUSI(@_);
