@@ -22,7 +22,9 @@ our $using_XML_LibXML_Simple;
 BEGIN {
     # Use XML::LibXML::Simple when possible, but it's not available on
     # all platforms (e.g. MacOS X v10.5.8) so be prepared to back down
-    # to XML::Simple.
+    # to XML::Simple. Pathetically, the API of XML::LibXML::Simple is
+    # not backwards compatible, so we need to know which we're
+    # using. Sheesh.
     eval {
 	require 'XML/LibXML/Simple.pm';
 	import XML::LibXML::Simple;
@@ -40,7 +42,7 @@ sub new {
     my $class = shift();
     my($admin, $ws) = @_;
 
-    warn "WARNING: making $class with non-torus2 WS '$ws'"
+    die "WARNING: making $class with non-torus2 WS '$ws'"
 	if $ws !~ /\/torus2\//;
 
     my $this = bless {
@@ -343,14 +345,6 @@ sub _recordByArgs {
 }
 
 
-sub recordURI {
-    my $this = shift();
-    my($listType, $realm, $id) = @_;
-
-    return $this->recordURIbyArgs(listType => $listType, realm => $realm, id => $id);
-}
-
-
 sub recordURIbyArgs {
     my $this = shift();
     my(%args) = @_;
@@ -414,41 +408,6 @@ sub _get {
     return $res;
 }
 
-sub _put {
-    my $this = shift();
-    my($uri, $xml) = @_;
-
-    $this->log(Masterkey::Admin::LogLevel::TORUS, "PUT $uri");
-    $this->log(Masterkey::Admin::LogLevel::WSPUT, $xml);
-    my $res = $this->{ua}->request(PUT($uri, Content => $xml,
-		   "Content-Type" => "application/xml"))
-	or die "no response for PUT to '$uri'\n";
-
-    if (!$res->is_success()) {
-	$this->_http_fatal("PUT to", $uri, $res);
-    }
-
-    return $res;
-}
-
-sub _post {
-    my $this = shift();
-    my($uri, $xml) = @_;
-
-    $this->log(Masterkey::Admin::LogLevel::TORUS, "POST $uri");
-    $this->log(Masterkey::Admin::LogLevel::WSPOST, $xml);
-    my $res = $this->{ua}->request(POST($uri, Content => $xml,
-		   "Content-Type" => "application/xml"))
-	or die "no response for POST to '$uri'\n";
-
-    if (!$res->is_success()) {
-	$this->_http_fatal("POST to", $uri, $res);
-    }
-
-    return $res;
-}
-
-
 sub _decompress_content {
     my $this = shift();
     my($res) = @_;
@@ -470,6 +429,34 @@ sub _decompress_content {
 }
 
 
+sub _put {
+    my $this = shift();
+    return $this->_put_or_post('PUT', Masterkey::Admin::LogLevel::WSPUT, \&PUT, @_);
+}
+
+sub _post {
+    my $this = shift();
+    return $this->_put_or_post('POST', Masterkey::Admin::LogLevel::WSPOST, \&POST, @_);
+}
+
+sub _put_or_post {
+    my $this = shift();
+    my($label, $loglevel, $method, $uri, $xml) = @_;
+
+    $this->log(Masterkey::Admin::LogLevel::TORUS, "x$label $uri");
+    $this->log($loglevel, $xml);
+    my $res = $this->{ua}->request($method->($uri, Content => $xml,
+		   "Content-Type" => "application/xml"))
+	or die "no response for $label to '$uri'\n";
+
+    if (!$res->is_success()) {
+	$this->_http_fatal("$label to", $uri, $res);
+    }
+
+    return $res;
+}
+
+
 # $goneHash is a reference to a hash whose keys are the names of
 # fields that should be removed completely from the record.
 sub update {
